@@ -38,5 +38,11 @@ def create_pastaporto_action(
     return PastaportoAction(action=action, payload=payload)
 
 
-def create_user_auth_pastaporto_action(user_id: int) -> PastaportoAction:
-    return create_pastaporto_action(Action.AUTH, {"id": user_id})
+def create_user_auth_pastaporto_action(user_id: int, jwt_auth_id: int) -> PastaportoAction:
+    return create_pastaporto_action(
+        Action.AUTH,
+        {
+            "id": user_id,
+            'jwt_auth_id': jwt_auth_id
+        }
+    )
